@@ -20,10 +20,8 @@ public:
     virtual int forward(const VkMat& bottom_blob, VkMat& top_blob, VkCompute& cmd, const Option& opt) const;
 
 public:
-    Pipeline* pipeline_cast_fp32_to_fp16;
-    Pipeline* pipeline_cast_fp32_to_fp16_pack4;
-    Pipeline* pipeline_cast_fp16_to_fp32;
-    Pipeline* pipeline_cast_fp16_to_fp32_pack4;
+    Pipeline* pipeline_cast;
+    Pipeline* pipeline_cast_pack4;
 };
 
 } // namespace ncnn
