@@ -11,6 +11,7 @@ namespace ncnn {
 Deconvolution_vulkan::Deconvolution_vulkan()
 {
     support_vulkan = true;
+    support_vulkan_packing = true;
 
     crop = 0;
     output_crop = 0;
@@ -70,7 +71,7 @@ int Deconvolution_vulkan::create_pipeline(const Option& _opt)
 
     size_t elemsize;
     size_t out_elemsize;
-    if (opt.use_fp16_storage || opt.use_fp16_packed)
+    if (opt.use_fp16_storage || opt.use_fp16_packed || opt.use_bf16_storage || opt.use_bf16_packed)
     {
         elemsize = elempack * 2u;
         out_elemsize = out_elempack * 2u;
