@@ -10,6 +10,7 @@ namespace ncnn {
 Slice_vulkan::Slice_vulkan()
 {
     support_vulkan = true;
+    support_vulkan_packing = true;
 
     pipeline_slice[0] = 0;
     pipeline_slice[1] = 0;
@@ -55,7 +56,7 @@ int Slice_vulkan::create_pipeline(const Option& opt)
     }
 
     size_t out_elemsize;
-    if (opt.use_fp16_storage || opt.use_fp16_packed)
+    if (opt.use_fp16_storage || opt.use_fp16_packed || opt.use_bf16_storage || opt.use_bf16_packed)
     {
         out_elemsize = out_elempack * 2u;
     }
