@@ -125,6 +125,7 @@ public:
     int quantize_embed();
     int quantize_gemm();
     int quantize_multiheadattention();
+    int quantize_sdpa();
 
     int fuse_requantize();
 };
@@ -842,6 +843,25 @@ int NetQuantize::quantize_multiheadattention()
     return 0;
 }
 
+int NetQuantize::quantize_sdpa()
+{
+    for (size_t i = 0; i < layers.size(); i++)
+    {
+        if (layers[i]->type != "SDPA")
+            continue;
+
+        ncnn::SDPA* sdpa = (ncnn::SDPA*)layers[i];
+
+        fprintf(stderr, "quantize_sdpa %s\n", sdpa->name.c_str());
+
+        // TODO move to ncnn2table
+
+        sdpa->int8_scale_term = 2;
+    }
+
+    return 0;
+}
+
 int NetQuantize::fuse_requantize()
 {
     const size_t layer_count = layers.size();
@@ -1093,6 +1113,7 @@ int main(int argc, char** argv)
     quantizer.quantize_embed();
     quantizer.quantize_gemm();
     quantizer.quantize_multiheadattention();
+    quantizer.quantize_sdpa();
 
     quantizer.fuse_requantize();
 
